@@ -86,6 +86,9 @@ prais_winsten <- function(formula, data, index, max_iter = 50L, tol = 1e-6,
 
   panel <- FALSE
   if (!is.null(index)){
+    if (length(index) > 2) {
+      stop("Argument 'index' can only have up to 2 elements.")
+    }
     if (length(index) == 2) {
       panel <- TRUE
     } else {
